#
# spec file for package timescaledb
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         pg_name  postgresql17%{nil}
%define         ext_name   timescaledb
%{pg_version_from_name}

Name:           %{pg_name}-%{ext_name}
Version:        2.19.3
Release:        1.1
Summary:        A time-series database extension for PostgreSQL
License:        Apache-2.0
Group:          Productivity/Databases/Tools
URL:            https://www.timescale.com/
Source:         https://github.com/timescale/%{ext_name}/archive/%{version}/%{ext_name}-%{version}.tar.gz

BuildRequires:  %{pg_name}-server-devel
BuildRequires:  cmake >= 3.11
%pg_server_requires
%if "%{pg_name}" == ""
ExclusiveArch:  do_not_build
Name:           %{ext_name}
%endif

%description
TimescaleDB is a database for making SQL more scalable for
time-series data. It is engineered up from PostgreSQL, providing
automatic partitioning across time and space (partitioning key), as
well as full SQL support.

TimescaleDB is packaged as a PostgreSQL extension.

This build includes only Apache2 modules;
TSL (timescale licenced modules are not built).

%prep
%autosetup -p1 -n %{ext_name}-%{version}

%build
%cmake -DAPACHE_ONLY=1 -DSEND_TELEMETRY_DEFAULT=OFF -DREGRESS_CHECKS=OFF
%cmake_build

%install
%cmake_install

%files
%license LICENSE-APACHE NOTICE LICENSE
%doc README.md CONTRIBUTING.md CHANGELOG.md
%{pg_config_pkglibdir}/%{ext_name}*.so
%{pg_config_sharedir}/extension/%{ext_name}*

%changelog
* Tue Apr 15 2025 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.19.3
  https://github.com/timescale/timescaledb/releases/tag/2.19.3
* Mon Apr  7 2025 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.19.2
  https://github.com/timescale/timescaledb/releases/tag/2.19.2
* Tue Apr  1 2025 Emiliano Langella <emiliano.langella@suse.com>
- Update to version 2.19.1
  https://github.com/timescale/timescaledb/releases/tag/2.19.1
* Tue Mar 18 2025 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.19.0
  https://github.com/timescale/timescaledb/releases/tag/2.19.0
* Wed Feb 19 2025 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.18.2
  https://github.com/timescale/timescaledb/releases/tag/2.18.2
* Mon Feb 10 2025 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.18.1
  https://github.com/timescale/timescaledb/releases/tag/2.18.1
* Thu Jan 23 2025 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.18.0
  https://github.com/timescale/timescaledb/releases/tag/2.18.0
* Thu Nov  7 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.17.2
  https://github.com/timescale/timescaledb/releases/tag/2.17.2
* Mon Oct 21 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.17.1
  https://github.com/timescale/timescaledb/releases/tag/2.17.1
* Tue Oct  8 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.17.0
  https://github.com/timescale/timescaledb/releases/tag/2.17.0
- drop series file
- enable pg17
* Tue Aug  6 2024 Marcus Rueckert <mrueckert@suse.de>
- drop pg 13 as flavor as it is unsupported now
* Tue Aug  6 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.16.1
  https://github.com/timescale/timescaledb/releases/tag/2.16.1
* Wed Jul 31 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.16.0
  https://github.com/timescale/timescaledb/releases/tag/2.16.0
* Tue Jul  2 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.15.3
  https://github.com/timescale/timescaledb/releases/tag/2.15.3
* Fri Jun  7 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.15.2
  https://github.com/timescale/timescaledb/releases/tag/2.15.2
* Tue May 28 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.15.1
  https://github.com/timescale/timescaledb/releases/tag/2.15.1
* Wed May  8 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.15.0
  https://github.com/timescale/timescaledb/releases/tag/2.15.0
* Tue Feb 20 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.14.2
  https://github.com/timescale/timescaledb/releases/tag/2.14.2
* Fri Feb 16 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.14.1
  https://github.com/timescale/timescaledb/releases/tag/2.14.1
* Fri Feb  9 2024 Emiliano Langella <emiliano.langella@suse.com>
- Update to version 2.14.0
  https://github.com/timescale/timescaledb/releases/tag/2.14.0
* Tue Jan  9 2024 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.13.1
  https://github.com/timescale/timescaledb/releases/tag/2.13.1
* Tue Nov 28 2023 Marcus Rueckert <mrueckert@suse.de>
- enable pg 16
* Tue Nov 28 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.13.0
  https://github.com/timescale/timescaledb/releases/tag/2.13.0
* Fri Oct 20 2023 Emiliano Langella <emiliano.langella@suse.com>
- Update to version 2.12.2
  https://github.com/timescale/timescaledb/releases/tag/2.12.2
* Thu Oct 12 2023 Marcus 'darix' Rückert <mrueckert@suse.de>
- Update to version 2.12.1
  https://github.com/timescale/timescaledb/releases/tag/2.12.1
* Tue Sep 26 2023 Marcus Rueckert <mrueckert@suse.de>
- drop pg 12. not supported. no pg 16 support yet either.
* Tue Sep 26 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.12.0
  https://github.com/timescale/timescaledb/releases/tag/2.12.0
* Thu Aug 17 2023 Emiliano Langella <emiliano.langella@suse.com>
- Update to version 2.11.2
  https://github.com/timescale/timescaledb/releases/tag/2.11.2
* Thu Jun 29 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.11.1
  https://github.com/timescale/timescaledb/releases/tag/2.11.1
* Mon May 22 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.11.0
  https://github.com/timescale/timescaledb/releases/tag/2.11.0
* Thu Apr 27 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.10.3
  https://github.com/timescale/timescaledb/releases/tag/2.10.3
* Thu Apr 20 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.10.2
  https://github.com/timescale/timescaledb/releases/tag/2.10.2
* Mon Mar 13 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.10.1
  https://github.com/timescale/timescaledb/releases/tag/2.10.1
* Tue Feb 21 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.10.0
  https://github.com/timescale/timescaledb/releases/tag/2.10.0
* Mon Feb  6 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.9.3
  https://github.com/timescale/timescaledb/releases/tag/2.9.3
* Tue Jan 31 2023 Marcus Rueckert <mrueckert@suse.de>
- enable pg 15 build
* Tue Jan 24 2023 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.9.2
  https://github.com/timescale/timescaledb/releases/tag/2.9.2
* Sat Dec 24 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.9.1
  https://github.com/timescale/timescaledb/releases/tag/2.9.1
* Tue Dec 20 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.9.0
  https://github.com/timescale/timescaledb/releases/tag/2.9.0
- dropped clang-format9_support.diff:
  minimum required version is now 14
* Mon Oct 10 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.8.1
  https://github.com/timescale/timescaledb/releases/tag/2.8.1
* Wed Aug 31 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.8.0
  https://github.com/timescale/timescaledb/releases/tag/2.8.0
- refreshed clang-format9_support.diff
* Sun Jul 31 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.7.2
  https://github.com/timescale/timescaledb/releases/tag/2.7.1
  https://github.com/timescale/timescaledb/releases/tag/2.7.2
* Tue May 24 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.7.0
  https://github.com/timescale/timescaledb/releases/tag/2.7.0
- drop ab6b90caf.patch: included upstream
* Tue Apr 12 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.6.1
  https://github.com/timescale/timescaledb/releases/tag/2.6.1
- refreshed patches:
  clang-format9_support.diff
  ab6b90caf.patch
* Tue Mar 15 2022 Bruno Friedmann <bruno@ioda-net.ch>
- Added patch ab6b90caf.patch containing explicit mention of
  CVE-2022-24128 closing boo#1197063
* Wed Feb 23 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.6.0
  https://github.com/timescale/timescaledb/releases/tag/2.6.0
* Thu Feb 10 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.5.2
  https://github.com/timescale/timescaledb/releases/tag/2.5.2
* Fri Jan 28 2022 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.5.1
  https://github.com/timescale/timescaledb/releases/tag/2.5.1
* Tue Nov 30 2021 Marcus Rueckert <mrueckert@suse.de>
- switch to %%{pg_name}-server-devel
* Tue Nov 30 2021 Marcus Rueckert <mrueckert@suse.de>
- Update to version 2.5.0
  https://github.com/timescale/timescaledb/releases/tag/1.7.5
  https://github.com/timescale/timescaledb/releases/tag/2.0.0
  https://github.com/timescale/timescaledb/releases/tag/2.0.1
  https://github.com/timescale/timescaledb/releases/tag/2.0.2
  https://github.com/timescale/timescaledb/releases/tag/2.1.0
  https://github.com/timescale/timescaledb/releases/tag/2.1.1
  https://github.com/timescale/timescaledb/releases/tag/2.2.0
  https://github.com/timescale/timescaledb/releases/tag/2.2.1
  https://github.com/timescale/timescaledb/releases/tag/2.3.0
  https://github.com/timescale/timescaledb/releases/tag/2.3.1
  https://github.com/timescale/timescaledb/releases/tag/2.4.0
  https://github.com/timescale/timescaledb/releases/tag/2.4.1
  https://github.com/timescale/timescaledb/releases/tag/2.4.2
  https://github.com/timescale/timescaledb/releases/tag/2.5.0
- enable postgresql14
- port to postgresql macros
- refresh clang-format9_support.diff
* Wed Jun 30 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Do not build postgresql96 flavor on Tumbleweed.
* Fri Sep 25 2020 Marcus Rueckert <mrueckert@suse.de>
- update to version 1.7.4
  https://github.com/timescale/timescaledb/releases/tag/1.7.2
  https://github.com/timescale/timescaledb/releases/tag/1.7.3
  https://github.com/timescale/timescaledb/releases/tag/1.7.4
* Wed Jun 17 2020 Bruno Friedmann <bruno@ioda-net.ch>
- update to version 1.7.1 bugfix
  https://github.com/timescale/timescaledb/releases/tag/1.7.1
  Please note that with the release of 1.7, support for PostgreSQL
  9.6.x and 10.x are deprecated. version 2 will only support 11,12
- Packaging :
  + Activate postgresql12 supported now
  + Modifiy download url to grab a nice named tar.gz
* Tue May  5 2020 Marcus Rueckert <mrueckert@suse.de>
- update to 1.7.0
  https://github.com/timescale/timescaledb/releases/tag/1.7.0
* Tue Mar 31 2020 Bruno Friedmann <bruno@ioda-net.ch>
  https://github.com/timescale/timescaledb/releases/tag/1.6.1
  https://github.com/timescale/timescaledb/releases/tag/1.6.0
  https://github.com/timescale/timescaledb/releases/tag/1.5.1
  https://github.com/timescale/timescaledb/releases/tag/1.5.0
  timescaledb doesn't offer support for postgresql 12 yet
- Packaging
  + spec-cleaner minimal
  + add patch to support clang version 9 clang-format9_support.diff
* Tue Oct 22 2019 Marcus Rueckert <mrueckert@suse.de>
- update to 1.4.2
  https://github.com/timescale/timescaledb/releases/tag/1.2.1
  https://github.com/timescale/timescaledb/releases/tag/1.2.2
  https://github.com/timescale/timescaledb/releases/tag/1.3.0
  https://github.com/timescale/timescaledb/releases/tag/1.3.1
  https://github.com/timescale/timescaledb/releases/tag/1.3.2
  https://github.com/timescale/timescaledb/releases/tag/1.4.0
  https://github.com/timescale/timescaledb/releases/tag/1.4.1
  https://github.com/timescale/timescaledb/releases/tag/1.4.2
* Tue Oct 22 2019 Marcus Rueckert <mrueckert@suse.de>
- adding postgresql12 to _multibuild
* Tue Feb  5 2019 Jan Engelhardt <jengelh@inai.de>
- Fix grammar. Trim duplicate metadata.
* Wed Jan 30 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to release 1.2.0 (2019-01-29)
  + Postgres 11 fully supported.
  + Deprecation of adaptive chunking
  + Advanced data lifecycle management : scheduled policies
    support scheduled drop_chunks and reorder.
  + Improved performance: support for ordered appends,
    Note that ordered appends do not support ordering by time_bucket
    at this time.
  + first release to include Timescale-Licensed features.
    LICENSE_TIMESCALE. This code can be found in tsl.
    (tsl is not build on openSUSE)
  + 1.1.1
  - Fix issue when upgrading with pg_upgrade
  - Fix a segfault that sometimes appeared in long COPYs
  - Other bug and stability fixes
- Packaging :
  + Add -DAPACHE_ONLY=1 to avoid tsl code and submodules
  + Multibuild : add postgresql11 now supported
  + Deps : revisit BuildRequires
* Wed Jan 30 2019 Bruno Friedmann <bruno@ioda-net.ch>
- Update to release 1.2.0 (2019-01-29)
  + Postgres 11 fully supported.
  + Deprecation of adaptive chunking
  + Advanced data lifecycle management : scheduled policies
    support scheduled drop_chunks and reorder.
  + Improved performance: support for ordered appends,
    Note that ordered appends do not support ordering by time_bucket
    at this time.
  + first release to include Timescale-Licensed features.
    LICENSE_TIMESCALE. This code can be found in tsl.
    (tsl is not build on openSUSE)
  + 1.1.1
  - Fix issue when upgrading with pg_upgrade
  - Fix a segfault that sometimes appeared in long COPYs
  - Other bug and stability fixes
- Packaging :
  + Add -DAPACHE_ONLY=1 to avoid tsl code and submodules
  + Multibuild : add postgresql11 now supported
  + Deps : revisit BuildRequires
* Wed Nov 28 2018 Bruno Friedmann <bruno@ioda-net.ch>
- Update to final release version 1.0.0 (2018-10-31)
  For complete changelog see
  https://github.com/timescale/timescaledb/releases
  or CHANGELOG file packaged
- LICENSE file was renammed to LICENSE-APACHE
- Packaging renew spec with spec-cleaner -m
* Fri May 18 2018 jengelh@inai.de
- Trim redundancies from the description.
* Sat May  5 2018 bruno@ioda-net.ch
- Update to release 0.9.2 (2018-05-04)
  + High-level changes
    Fixed handling of DISCARD ALL command when parallel workers are
    involved, which sometimes caused the extension to complain it
    was not preloaded
    User permission bug fix where users locating TRIGGER permissions
    in a database could not insert data into a hypertable
  + Fixes for some issues with 32-bit architectures
- Changes for 0.9.1
  + High-level changes
    For this release only, you will need to restart the database
    before running ALTER EXTENSION
    Several edge cases regarding CTEs addressed
    Updated preloader with better error messaging and fixed edge case
    ABI compatibility with latest PostgreSQL to help catch any
    breaking changes
- Changes for 0.9.0
  + When updating your database, you should connect using
    psql with the -X flag to prevent any .psqlrc commands from
    accidentally triggering the load of a previous DB version.
  + High-level changes
    Support for multiple extension versions on different databases
    in the same PostgreSQL instance.
    This allows different databases to be updated independently
    and provides for smoother updates between versions. No
    more spurious errors in the log as the extension is being
    updated, and new versions no longer require a restart of
    the database.
  + Streamlined update process for smaller binary/package sizes
  + Significant refactoring to simplify and improve codebase,
    including improvements to error handling, security/permissions
  + Corrections to edge-case scenarios involving dropping schemas,
    hypertables, dimensions, and more
  + Correctness improvements through propagating reloptions from main
    table to chunk tables and blocking ONLY commands that try to alter
    hypertables (i.e., changes should be applied to chunks as well)
  + Addition of a migrate_data option to create_hypertable to allow
    non-empty tables to be turned into hypertables without separate
    creation & insertion steps. Note, this option may take a while
    if the original table has lots of data
  + Support for ALTER TABLE RENAME CONSTRAINT
  + Support for adjusting the number of partitions for a space dimension
  + Improvements to tablespace handling
* Tue Feb  6 2018 bruno@ioda-net.ch
- Adapt cmake ld flags (no-as-needed) for build on Leap 42x/SLE12
* Sun Feb  4 2018 bruno@ioda-net.ch
- initial package
